summaryrefslogtreecommitdiffstats
path: root/kresources/kolab/kcal/resourcekolab.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/kolab/kcal/resourcekolab.cpp')
-rw-r--r--kresources/kolab/kcal/resourcekolab.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/kresources/kolab/kcal/resourcekolab.cpp b/kresources/kolab/kcal/resourcekolab.cpp
index 5bbae761..59f6a355 100644
--- a/kresources/kolab/kcal/resourcekolab.cpp
+++ b/kresources/kolab/kcal/resourcekolab.cpp
@@ -22,11 +22,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -285,7 +285,7 @@ void ResourceKolab::removeIncidences( const TQCString& incidenceType )
// better call event(uid), todo(uid) etc. directly.
// A faster but hackish way would probably be to check the type of the resource,
// like mEventSubResources.find( it.data().resource() ) != mEventSubResources.end() ?
const TQString& uid = it.key();
if ( incidenceType == "Event" && mCalendar.event( uid ) )
mUidMap.remove( it );
@@ -726,7 +726,7 @@ bool ResourceKolab::addIncidence( KCal::Incidence* incidence, const TQString& _s
}
}
/* Check if there are updates for this uid pending and if so process them. */
- if ( KCal::IncidenceBase *update = mPendingUpdates.find( uid ) ) {
+ if ( KCal::IncidenceBase *update = mPendingUpdates.tqfind( uid ) ) {
mSilent = false; // we do want to tell KMail
mPendingUpdates.remove( uid );
incidenceUpdated( update );
@@ -920,7 +920,7 @@ KCal::Alarm::List ResourceKolab::relevantAlarms( const KCal::Alarm::List &alarms
while ( it != alarms.end() ) {
KCal::Alarm *a = (*it);
++it;
- const TQString &uid = a->parent()->uid();
+ const TQString &uid = a->tqparent()->uid();
if ( mUidMap.tqcontains( uid ) ) {
const TQString &sr = mUidMap[ uid ].resource();
Kolab::SubResource *subResource = 0;
@@ -1009,15 +1009,15 @@ void ResourceKolab::fromKMailDelIncidence( const TQString& type,
if ( !subresourceActive( subResource ) ) return;
// Can't be in both, by contract
- if ( mUidsPendingDeletion.find( uid ) != mUidsPendingDeletion.end() ) {
- mUidsPendingDeletion.remove( mUidsPendingDeletion.find( uid ) );
+ if ( mUidsPendingDeletion.tqfind( uid ) != mUidsPendingDeletion.end() ) {
+ mUidsPendingDeletion.remove( mUidsPendingDeletion.tqfind( uid ) );
} else if ( mUidsPendingUpdate.tqcontains( uid ) ) {
// It's good to know if was deleted, but we are waiting on a new one to
- // tqreplace it, so let's just sit tight.
+ // replace it, so let's just sit tight.
} else {
TQString uidToUse;
- QPair<TQString, TQString> p( uid, subResource );
+ TQPair<TQString, TQString> p( uid, subResource );
if ( mOriginalUID2fakeUID.tqcontains( p ) ) {
// Incidence with the same uid in a different folder...
// use the UID that addIncidence(...) generated
@@ -1119,7 +1119,7 @@ TQStringList ResourceKolab::subresources() const
+ mJournalSubResources.keys() );
}
-const QString
+const TQString
ResourceKolab::labelForSubresource( const TQString& subresource ) const
{
if ( mEventSubResources.tqcontains( subresource ) )
@@ -1231,22 +1231,22 @@ Kolab::ResourceMap* ResourceKolab::subResourceMap( const TQString& contentsType
/*virtual*/
-bool ResourceKolab::addSubresource( const TQString& resource, const TQString& parent )
+bool ResourceKolab::addSubresource( const TQString& resource, const TQString& tqparent )
{
kdDebug(5650) << "KCal Kolab resource - adding subresource: " << resource << endl;
TQString contentsType = kmailCalendarContentsType;
- if ( !parent.isEmpty() ) {
- if ( mEventSubResources.tqcontains( parent ) )
+ if ( !tqparent.isEmpty() ) {
+ if ( mEventSubResources.tqcontains( tqparent ) )
contentsType = kmailCalendarContentsType;
- else if ( mTodoSubResources.tqcontains( parent ) )
+ else if ( mTodoSubResources.tqcontains( tqparent ) )
contentsType = kmailTodoContentsType;
- else if ( mJournalSubResources.tqcontains( parent ) )
+ else if ( mJournalSubResources.tqcontains( tqparent ) )
contentsType = kmailJournalContentsType;
} else {
TQStringList contentTypeChoices;
contentTypeChoices << i18n("Calendar") << i18n("Tasks") << i18n("Journals");
const TQString caption = i18n("Which kind of subresource should this be?");
- const TQString choice = KInputDialog::getItem( caption, TQString::null, contentTypeChoices );
+ const TQString choice = KInputDialog::getItem( caption, TQString(), contentTypeChoices );
if ( choice == contentTypeChoices[0] )
contentsType = kmailCalendarContentsType;
else if ( choice == contentTypeChoices[1] )
@@ -1255,7 +1255,7 @@ bool ResourceKolab::addSubresource( const TQString& resource, const TQString& pa
contentsType = kmailJournalContentsType;
}
- return kmailAddSubresource( resource, parent, contentsType );
+ return kmailAddSubresource( resource, tqparent, contentsType );
}
/*virtual*/
@@ -285,7 +285,7 @@ void ResourceKolab::removeIncidences( const TQCString& incidenceType )
// better call event(uid), todo(uid) etc. directly.
// A faster but hackish way would probably be to check the type of the resource,
- // like mEventSubResources.find( it.data().resource() ) != mEventSubResources.end() ?
+ // like mEventSubResources.tqfind( it.data().resource() ) != mEventSubResources.end() ?
const TQString& uid = it.key();
if ( incidenceType == "Event" && mCalendar.event( uid ) )